===============================
Stockfighter
===============================

.. image:: https://img.shields.io/pypi/v/stockfighter.svg
        :target: https://pypi.python.org/pypi/stockfighter

.. image:: https://img.shields.io/travis/striglia/stockfighter.svg
        :target: https://travis-ci.org/striglia/stockfighter

.. image:: https://readthedocs.org/projects/stockfighter/badge/?version=latest
        :target: https://readthedocs.org/projects/stockfighter/?badge=latest
        :alt: Documentation Status


API wrapper for Stockfighter

* Free software: ISC license
* Documentation: https://stockfighter.readthedocs.org.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
